==> plasma-workspace-5.17.5.tar.xz: plasma-workspace-5.17.5/krunner/krunner.desktop.cmake <==
[Desktop Entry]
Exec=@CMAKE_INSTALL_PREFIX@/bin/krunner
Name=KRunner
Name[ar]=مشغّل.ك
Name[bs]=KPokretač
Name[ca]=KRunner
Name[ca@valencia]=KRunner
Name[cs]=KRunner
Name[da]=KRunner
Name[de]=KRunner
Name[el]=KRunner
Name[en_GB]=KRunner
Name[es]=KRunner
Name[et]=KRunner
Name[eu]=KRunner
Name[fi]=KRunner
Name[fr]=KRunner
Name[gl]=KRunner
Name[hu]=KRunner
Name[id]=KRunner
Name[is]=KRunner
Name[it]=KRunner
Name[ja]=KRunner
Name[ko]=KRunner
Name[lt]=KRunner
Name[nb]=KRunner
Name[nds]=KRunner
Name[nl]=KRunner
Name[nn]=KRunner
Name[pa]=ਕੇਰਨਰ
Name[pl]=KRunner
Name[pt]=KRunner
Name[pt_BR]=KRunner
Name[ru]=KRunner
Name[sk]=KRunner
Name[sl]=KRunner
Name[sr]=К‑извођач
Name[sr@ijekavian]=К‑извођач
Name[sr@ijekavianlatin]=K‑izvođač
Name[sr@latin]=K‑izvođač
Name[sv]=Kör program
Name[tr]=KRunner
Name[uk]=KRunner
Name[x-test]=xxKRunnerxx
Name[zh_CN]=KRunner
Name[zh_TW]=KRunner
OnlyShowIn=KDE;
Type=Application
X-DBUS-StartupType=Unique
X-DBUS-ServiceName=org.kde.krunner
X-KDE-StartupNotify=false
X-KDE-Shortcuts=Alt+Space,Alt+F2,Search
Actions=RunClipboard
X-KDE-Wayland-Interfaces=org_kde_plasma_window_management

[Desktop Action RunClipboard]
Exec=krunner -c
Name=Run command on clipboard contents
Name[ca]=Executa una ordre al contingut del porta-retalls
Name[ca@valencia]=Executa una ordre en el contingut del porta-retalls
Name[cs]=Spustit příkaz nad obsahem schránky
Name[da]=Kør kommando på udklipsholderindholdet
Name[de]=Befehl mit dem Inhalt der Zwischenablage ausführen
Name[en_GB]=Run command on clipboard contents
Name[es]=Ejecutar orden sobre el contenido del portapapeles
Name[eu]=Exekutatu komandoa arbelaren edukiaren gain
Name[fi]=Suorita komento leikepöydän sisällöstä
Name[fr]=Exécuter la commande en utilisant le contenu du presse-papier
Name[gl]=Executar a orde segundo o contido do portapapeis
Name[id]=Jalankan perintah pada konten-konten papan-klip
Name[it]=Esegui comando sui contenuti degli appunti
Name[ko]=클립보드 내용에서 명령 실행하기
Name[lt]=Vykdyti komandas su iškarpinės turiniu
Name[nl]=Commando uitvoeren op klembordinhoud
Name[nn]=Køyr kommando på innhaldet på utklippstavla
Name[pl]=Wykonaj polecenie na zawartości schowka
Name[pt]=Executar o comando no conteúdo da área de transferência
Name[pt_BR]=Executar comando no conteúdo da área de transferência
Name[ru]=Запуск команды из буфера обмена
Name[sk]=Spustiť príkaz na obsahu schránky
Name[sv]=Kör kommando med klippbordets innehåll
Name[uk]=Виконати команду над вмістом буфера обміну
Name[x-test]=xxRun command on clipboard contentsxx
Name[zh_CN]=在剪贴板内容上运行命令
Name[zh_TW]=執行剪貼簿內容中的指令
X-KDE-Shortcuts=Alt+Shift+F2

==> plasma-workspace-5.17.90.tar.xz: plasma-workspace-5.17.90/krunner/krunner.desktop.cmake <==
[Desktop Entry]
Exec=@CMAKE_INSTALL_PREFIX@/bin/krunner
Name=KRunner
Name[ar]=مشغّل.ك
Name[ast]=KRunner
Name[bs]=KPokretač
Name[ca]=KRunner
Name[ca@valencia]=KRunner
Name[cs]=KRunner
Name[da]=KRunner
Name[de]=KRunner
Name[el]=KRunner
Name[en_GB]=KRunner
Name[es]=KRunner
Name[et]=KRunner
Name[eu]=KRunner
Name[fi]=KRunner
Name[fr]=KRunner
Name[gl]=KRunner
Name[hu]=KRunner
Name[id]=KRunner
Name[is]=KRunner
Name[it]=KRunner
Name[ja]=KRunner
Name[ko]=KRunner
Name[lt]=KRunner
Name[nb]=KRunner
Name[nds]=KRunner
Name[nl]=KRunner
Name[nn]=KRunner
Name[pa]=ਕੇਰਨਰ
Name[pl]=KRunner
Name[pt]=KRunner
Name[pt_BR]=KRunner
Name[ru]=KRunner
Name[sk]=KRunner
Name[sl]=KRunner
Name[sr]=К‑извођач
Name[sr@ijekavian]=К‑извођач
Name[sr@ijekavianlatin]=K‑izvođač
Name[sr@latin]=K‑izvođač
Name[sv]=Kör program
Name[tr]=KRunner
Name[uk]=KRunner
Name[x-test]=xxKRunnerxx
Name[zh_CN]=KRunner
Name[zh_TW]=KRunner
OnlyShowIn=KDE;
Type=Application
X-DBUS-StartupType=Unique
X-DBUS-ServiceName=org.kde.krunner
X-KDE-StartupNotify=false
X-KDE-Shortcuts=Alt+Space,Alt+F2,Search
Actions=RunClipboard
X-KDE-Wayland-Interfaces=org_kde_plasma_window_management

[Desktop Action RunClipboard]
Exec=krunner -c
Name=Run command on clipboard contents
Name[ca]=Executa una ordre al contingut del porta-retalls
Name[ca@valencia]=Executa una ordre en el contingut del porta-retalls
Name[cs]=Spustit příkaz nad obsahem schránky
Name[da]=Kør kommando på udklipsholderindholdet
Name[de]=Befehl mit dem Inhalt der Zwischenablage ausführen
Name[en_GB]=Run command on clipboard contents
Name[es]=Ejecutar orden sobre el contenido del portapapeles
Name[et]=Käsu käivitamine lõikepuhvri sisuga
Name[eu]=Exekutatu komandoa arbelaren edukiaren gain
Name[fi]=Suorita komento leikepöydän sisällöstä
Name[fr]=Exécuter la commande en utilisant le contenu du presse-papier
Name[gl]=Executar a orde segundo o contido do portapapeis
Name[hu]=Parancs futtatása a vágólap tartalmával
Name[id]=Jalankan perintah pada konten-konten papan-klip
Name[it]=Esegui comando sui contenuti degli appunti
Name[ko]=클립보드 내용에서 명령 실행하기
Name[lt]=Vykdyti komandas su iškarpinės turiniu
Name[nl]=Commando uitvoeren op klembordinhoud
Name[nn]=Køyr kommando på innhaldet på utklippstavla
Name[pl]=Wykonaj polecenie na zawartości schowka
Name[pt]=Executar o comando no conteúdo da área de transferência
Name[pt_BR]=Executar comando no conteúdo da área de transferência
Name[ru]=Запуск команды из буфера обмена
Name[sk]=Spustiť príkaz na obsahu schránky
Name[sv]=Kör kommando med klippbordets innehåll
Name[uk]=Виконати команду над вмістом буфера обміну
Name[x-test]=xxRun command on clipboard contentsxx
Name[zh_CN]=在剪贴板内容上运行命令
Name[zh_TW]=執行剪貼簿內容中的指令
X-KDE-Shortcuts=Alt+Shift+F2
